pub trait AsyncConnWithInfo: AsyncConn + TlsInfoFactory { }Expand description
Trait representing an async connection which can provide TLS info.
pub trait AsyncConnWithInfo: AsyncConn + TlsInfoFactory { }Trait representing an async connection which can provide TLS info.